@@ -285,8 +285,8 @@ class Chemical:
     A model handle contains a series of models applicable to a certain domain:
     
     >>> Water.Psat[0].show()
-    TDependentModel: Wagner McGraw
-     evaluate: Wagner_McGraw(T, P=None) -> Psat [Pa]
+    TDependentModel(T, P=None) -> Psat [Pa]
+     name: Wagner McGraw
      Tmin: 275 K
      Tmax: 647.35 K
 
@@ -348,8 +348,8 @@ class Chemical:
     ... # Model is appended at the end by default
     >>> added_model = Water.V.l[-1]
     >>> added_model.show()
-    ConstantThermoModel: Constant
-     value (V.l): 1.687e-05 m^3/mol
+    ConstantThermoModel(T=None, P=None) -> V.l [m^3/mol]
+     value: 1.687e-05
      Tmin: 0 K
      Tmax: inf K
      Pmin: 0 Pa
