@@ -18,7 +18,7 @@ setattr = object.__setattr__
 
 def must_compile(*args, **kwargs):
     raise TypeError("method valid only for compiled chemicals; "
-                    "run <chemicals>.compile() to compile")
+                    "run <Chemicals>.compile() to compile")
 
 def chemical_data_array(chemicals, attr):
     getfield = getattr
