@@ -9,7 +9,7 @@ from ._thermal_condition import ThermalCondition
 from .indexer import MolarFlowIndexer
 from ._settings import settings
 from .equilibrium import VLE, LLE
-from .utils import Cache, all_same_chemicals
+from .utils import Cache
 import numpy as np
 
 __all__ = ('MultiStream', )
@@ -168,7 +168,7 @@ class MultiStream(Stream):
     def __init__(self, ID="", flow=(), T=298.15, P=101325.,
                  phases=('g', 'l'), units=None,
                  thermo=None, price=0, **phase_flows):
-        self._TP = ThermalCondition(T, P)
+        self._thermal_condition = ThermalCondition(T, P)
         thermo = self._load_thermo(thermo)
         self._init_indexer(flow, phases, thermo.chemicals, phase_flows)
         self.price = price
@@ -198,10 +198,10 @@ class MultiStream(Stream):
     def _init_cache(self):
         super()._init_cache()
         self._streams = {}
-        self._vle_cache = Cache(VLE, self._imol, self._TP, thermo=self._thermo,
+        self._vle_cache = Cache(VLE, self._imol, self._thermal_condition, thermo=self._thermo,
                                 bubble_point_cache=self._bubble_point_cache,
                                 dew_point_cache=self._dew_point_cache)
-        self._lle_cache = Cache(LLE, self._imol, self._TP, self._thermo)
+        self._lle_cache = Cache(LLE, self._imol, self._thermal_condition, self._thermo)
         
     def __getitem__(self, phase):
         streams = self._streams
@@ -212,7 +212,7 @@ class MultiStream(Stream):
             stream._sink = stream._source = None
             stream._imol = self._imol.get_phase(phase)
             stream._ID = None
-            stream._TP = self._TP
+            stream._thermal_condition = self._thermal_condition
             stream._thermo = self._thermo
             streams[phase] = stream
         return stream
@@ -286,7 +286,7 @@ class MultiStream(Stream):
         phases = sorted(phases)
         if phases != self.phases:
             self._imol = self._imol.to_material_array(phases)
-            self._vle_cache = Cache(VLE, self._imol, self._TP, thermo=self._thermo)
+            self._init_cache()
     
     ### Flow properties ###
             
@@ -314,23 +314,23 @@ class MultiStream(Stream):
     @property
     def H(self):
         """[float] Enthalpy flow rate in kJ/hr."""
-        return self.mixture.xH_at_TP(self._imol, self._TP)
+        return self.mixture.xH(self._imol, *self._thermal_condition)
     @H.setter
     def H(self, H):
-        self.T = self.mixture.xsolve_T(self._imol, H, self.T, self.P)
+        self.T = self.mixture.xsolve_T(self._imol, H, *self._thermal_condition)
 
     @property
     def S(self):
         """[float] Entropy flow rate in kJ/hr."""
-        return self.mixture.xS_at_TP(self._imol, self._TP)
+        return self.mixture.xS(self._imol, *self._thermal_condition)
     @property
     def C(self):
         """[float] Heat capacity flow rate in kJ/hr."""
-        return self.mixture.xCn_at_TP(self._imol, self._TP)
+        return self.mixture.xCn(self._imol, *self._thermal_condition)
     @property
     def F_vol(self):
         """[float] Total volumetric flow rate in m3/hr."""
-        return 1000. * self.mixture.xV_at_TP(self._imol, self._TP)
+        return 1000. * self.mixture.xV(self._imol, *self._thermal_condition)
     @F_vol.setter
     def F_vol(self, value):
         F_vol = self.F_vol
@@ -340,7 +340,7 @@ class MultiStream(Stream):
     @property
     def Hvap(self):
         """[float] Enthalpy of vaporization flow rate in kJ/hr."""
-        return self.mixture.Hvap_at_TP(self._imol['l'], self._TP)
+        return self.mixture.Hvap(self._imol['l'], *self._thermal_condition)
     
     ### Composition properties ###
     
@@ -356,30 +356,30 @@ class MultiStream(Stream):
     @property
     def V(self):
         """[float] Molar volume [m^3/mol]."""
-        return self.mixture.xV_at_TP(self._imol.iter_composition(), self._TP)
+        return self.mixture.xV(self._imol.iter_composition(), *self._thermal_condition)
     @property
     def kappa(self):
         """[float] Thermal conductivity [W/m/k]."""
-        return self.mixture.xkappa_at_TP(self._imol.iter_composition(), self._TP)        
+        return self.mixture.xkappa(self._imol.iter_composition(), *self._thermal_condition)        
     @property
     def Cn(self):
         """[float] Molar heat capacity [J/mol/K]."""
-        return self.mixture.xCn_at_TP(self._imol.iter_composition(), self._TP)
+        return self.mixture.xCn(self._imol.iter_composition(), self.T)
     @property
     def mu(self):
         """[float] Hydrolic viscosity [Pa*s]."""
-        return self.mixture.xmu_at_TP(self._imol.iter_composition(), self._TP)
+        return self.mixture.xmu(self._imol.iter_composition(), *self._thermal_condition)
 
     @property
     def sigma(self):
         """[float] Surface tension [N/m]."""
         mol = self._imol['l']
-        return self.mixture.sigma_at_TP(mol / mol.sum(), self._TP)
+        return self.mixture.sigma(mol / mol.sum(), *self._thermal_condition)
     @property
     def epsilon(self):
         """[float] Relative permittivity [-]."""
         mol = self._imol['l']
-        return self.mixture.epsilon_at_TP(mol / mol.sum(), self._TP)
+        return self.mixture.epsilon(mol / mol.sum(), *self._thermal_condition)
         
     ### Methods ###
     
@@ -460,7 +460,7 @@ class MultiStream(Stream):
     def link_with(self, other):
         if settings._debug:
             assert isinstance(other, self.__class__), "other must be of same type to link with"
-        self._TP = other._TP
+        self._thermal_condition = other._thermal_condition
         self._imol._data = other._imol._data
         self._streams = other._streams
         self._vle_cache = other._vle_cache
