@@ -69,8 +69,6 @@ def functor(f=None, var=None, **autodoc):
         or both temperature and pressure.
     var : str, optional
         Name of variable returned (useful for bookkeeping).
-    wrap : function
-        Should return a dictionary of arguments to pass to the fist function argument.
     **autodoc : 
         Options to autodoc Functor subclass. By default, the returned Functor subclass is not automatically documented.
     
@@ -107,7 +105,6 @@ def functor(f=None, var=None, **autodoc):
                'params': params,
                'var': var}
         cls = type(f.__name__, (base,), dct)
-        cls._autodoc_ = autodoc
         if autodoc: autodoc_functor(cls, **autodoc)
         cls.__module__ = f.__module__
         return cls
@@ -147,7 +144,6 @@ H, S, Cn, V, kappa, mu, Psat, Hvap, sigma, delta, epsilon = [FunctorFactory(i) f
 # %% Functors
 
 class Functor: 
-    __slots__ = ('data',)
     definitions = definitions
     types = types
     
@@ -169,6 +165,13 @@ class Functor:
         for i, j in zip(self.params, args): kwargs[i] = j
         self.data = kwargs
     
+    @property
+    def data(self):
+        return self.__dict__
+    @data.setter
+    def data(self, data):
+        self.__dict__ = data
+    
     @classmethod
     def from_other(cls, other):
         self = cls.__new__(cls)
@@ -248,24 +251,21 @@ class Functor:
 
 
 class TFunctor(Functor, args=('T',)):
-    __slots__ = ()
     kind = "functor of temperature (T; in K)"
     def __call__(self, T, P=None):
-        return self.function(T, **self.data)
+        return self.function(T, **self.__dict__)
 
 
 class TIntegralFunctor(Functor, args=('Ta', 'Tb')):
-    __slots__ = ()
     kind = "temperature integral functor (Ta to Tb; in K)"
     def __call__(self, Ta, Tb, P=None):
-        return self.function(Ta, Tb, **self.data)
+        return self.function(Ta, Tb, **self.__dict__)
 
 
 class TPFunctor(Functor, args=('T', 'P')):
-    __slots__ = ()
     kind = "functor of temperature (T; in K) and pressure (P; in Pa)"
     def __call__(self, T, P):
-        return self.function(T, P, **self.data)
+        return self.function(T, P, **self.__dict__)
 
 
     
