@@ -148,8 +148,11 @@ class ThermoModel:
     def __call__(self):
         return self.evaluate
     
+    def __str__(self):
+        return display_asfunctor(self.evaluate, self.var, type(self).__name__)
+    
     def __repr__(self):
-        return f"<{type(self).__name__}: {self.name}>"
+        return f"<{self}>"
 
 
 class TDependentModel(ThermoModel, Functor=TFunctor):
@@ -190,8 +193,8 @@ class TDependentModel(ThermoModel, Functor=TFunctor):
         return (Pb - Pa) * self(T)
     
     def show(self):
-        print(f"{type(self).__name__}: {self.name}\n"
-              f" evaluate: {display_asfunctor(self.evaluate)}\n"
+        print(f"{self}\n"
+              f" name: {self.name}\n"
               f" Tmin: {self.Tmin:.5g} K\n"
               f" Tmax: {self.Tmax:.5g} K")
         
@@ -236,8 +239,8 @@ class TPDependentModel(ThermoModel, Functor=TPFunctor):
         return (self.evaluate(T, P+dP) - self.evaluate(T, P))/dP
 
     def show(self):
-        print(f"{type(self).__name__}: {self.name}\n"
-              f" evaluate: {display_asfunctor(self.evaluate)}\n"
+        print(f"{self}\n"
+              f" name: {self.name}\n"
               f" Tmin: {self.Tmin:.5g} K\n"
               f" Tmax: {self.Tmax:.5g} K\n"
               f" Pmin: {self.Pmin:.5g} Pa\n"
@@ -298,17 +301,8 @@ class ConstantThermoModel(ThermoModel):
         return 0
 
     def show(self):
-        if self.var :
-            var = f' ({self.var})'
-            var_no_phase, *_ = self.var.split('.')
-            if var_no_phase in chemical_units_of_measure:
-                units = " " + str(chemical_units_of_measure[var_no_phase])
-            else:
-                units = ""
-        else:
-            var = units = ""
-        print(f"{type(self).__name__}: {self.name}\n"
-              f" value{var}: {self.value}{units}\n"
+        print(f"{self}\n"
+              f" value: {self.value}\n"
               f" Tmin: {self.Tmin:.5g} K\n"
               f" Tmax: {self.Tmax:.5g} K\n"
               f" Pmin: {self.Pmin:.5g} Pa\n"
@@ -353,8 +347,8 @@ class InterpolatedTDependentModel(ThermoModel):
     differentiate_by_P = TDependentModel.differentiate_by_P
     
     def show(self):
-        print(f"{type(self).__name__}: {self.name}\n"
-              f" evaluate: {display_asfunctor(self.evaluate, self.var)}"
+        print(f"{self}\n"
+              f" name: {self.name}"
               f" Tmin: {self.Tmin:.2f}\n"
               f" Tmax: {self.Tmax:.2f}")
 
