@@ -21,7 +21,7 @@ __all__ = ('ThermoModelHandle',
            'TPDependentModelHandle')
 
 # %% Utilities
-    
+
 def find_model_by_name(models, name):
     for model in models:
         if model.name == name: return model
@@ -254,6 +254,7 @@ class TDependentModelHandle(ThermoModelHandle):
             if model.indomain(T): return model.evaluate(T)
         raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
                          f"at T={T:.2f} K")
+    at_T = __call__
     
     def try_out(self, T, P=None):
         for model in self.models:
@@ -335,6 +336,13 @@ class TPDependentModelHandle(ThermoModelHandle):
             if model.indomain(T, P): return model.evaluate(T, P)
         raise DomainError(f"{no_valid_model(self.chemical, self.var)} "
                          f"at T={T:.2f} K and P={P:.0f} Pa")
+    def at_T(self, T):
+        isa = isinstance
+        for model in self.models:
+            if isa(model, TDependentModel) and model.indomain(T):
+                return model.evaluate(T)
+        raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
+                         f"at T={T:.2f} K")
 
     def try_out(self, T, P):
         for model in self.models:
