@@ -5,8 +5,12 @@ Created on Mon Dec  2 01:41:50 2019
 @author: yoelr
 """
 
-from .base import UnitsOfMeasure
-from .utils import repr_IDs_data, repr_couples, chemicals_user
+from .base import AbsoluteUnitsOfMeasure
+from .utils import (repr_IDs_data, repr_couples,
+                    chemicals_user,
+                    same_chemicals, same_phases,
+                    all_same_chemicals,
+)
 from ._settings import settings
 from .exceptions import UndefinedPhase, UndefinedChemical
 from ._phase import Phase, LockedPhase, NoPhase
@@ -29,6 +33,27 @@ __all__ = ('ChemicalIndexer',
 isa = isinstance
 _new = object.__new__
 
+def all_same_phase(indexers, phase):
+    for i in indexers:
+        if phase != i.phase: return False
+    return True
+
+def find_main_indexer(indexers, main_indexer):
+    max_total = main_indexer._data.sum()
+    for indexer in indexers:
+        total = indexer._data.sum()
+        if total > max_total:
+            max_total = total
+            main_indexer = indexer
+    return main_indexer
+
+def find_main_phase(chemical_indexers, main_indexer):
+    phase = main_indexer.phase
+    if not all_same_phase(chemical_indexers, phase):
+        main_indexer = find_main_indexer(chemical_indexers, main_indexer)
+        phase = main_indexer.phase
+    return phase
+
 def nonzeros(IDs, data):
     index, = np.where(data != 0)
     return [IDs[i] for i in index], data[index]
@@ -84,7 +109,9 @@ class Indexer:
 
 @chemicals_user
 class ChemicalIndexer(Indexer):
-    """Create a ChemicalIndexer that can index a single-phase, 1d-array given chemical IDs.
+    """
+    Create a ChemicalIndexer that can index a single-phase, 1d-array given
+    chemical IDs.
     
     Parameters
     ----------
@@ -99,8 +126,9 @@ class ChemicalIndexer(Indexer):
     
     Notes
     -----
-    A ChemicalIndexer does not have any units defined. To use units of measure, use the 
-    `ChemicalMolarIndexer`, `ChemicalMassIndexer`, or `ChemicalVolumetricIndexer`.
+    A ChemicalIndexer does not have any units defined. To use units of
+    measure, use the  `ChemicalMolarIndexer`, `ChemicalMassIndexer`, or
+    `ChemicalVolumetricIndexer`.
     
     """
     __slots__ = ('_chemicals', '_phase', '_data_cache')
@@ -122,17 +150,28 @@ class ChemicalIndexer(Indexer):
     def __setitem__(self, key, data):
         self._data[self.get_index(key)] = data
     
+    def sum_across_phases(self):
+        return self._data
+    
     @property
     def get_index(self):
         return self._chemicals.get_index
     
+    def empty(self):
+        self._data[:] = 0
+    
+    def mix_from(self, others):
+        all_same_chemicals(self, others)
+        self.phase = find_main_phase(others[1:], others[0]) or self.phase
+        self._data[:] = sum([i.sum_across_phases() for i in others])
+    
     def to_material_indexer(self, phases=()):
         material_array = self._MaterialIndexer.blank(phases, self._chemicals)
         material_array[self.phase] = self._data
         return material_array
     
     def copy_like(self, other):
-        assert self._chemicals is other._chemicals, "chemicals must match"
+        same_chemicals(self, other)
         self._data[:] = other._data
         self.phase = other.phase
     
@@ -234,7 +273,9 @@ class ChemicalIndexer(Indexer):
       
 @chemicals_user
 class MaterialIndexer(Indexer):
-    """Create a MaterialIndexer that can index a multi-phase, 2d-array given the phase and chemical IDs.
+    """
+    Create a MaterialIndexer that can index a multi-phase, 2d-array given
+    the phase and chemical IDs.
     
     Parameters
     ----------
@@ -275,13 +316,35 @@ class MaterialIndexer(Indexer):
     def __reduce__(self):
         return self.from_data, (self._data, self._phases, self._chemicals, False)
     
+    @property
+    def sum_across_phases(self):
+        return self._data.sum(0)
+    
+    def empty(self):
+        self._data[:] = 0
+    
     def copy_like(self, other):
+        same_chemicals(self, other)
         if isa(other, ChemicalIndexer):
-            self._data[:] = 0
+            self.empty()
             self[other.phase] = other._data
         else:
+            same_phases(self, other)
             self._data[:] = other._data
     
+    def mix_from(self, others):
+        all_same_chemicals(self, others)
+        self.empty()
+        isa = isinstance
+        for i in others:
+            if isa(i, MaterialIndexer):
+                same_phases(self, i)
+                self._data[:] += i._data
+            elif isa(i, ChemicalIndexer):
+                self[i.phase] += i._data
+            else:
+                raise ValueError("can only mix from chemical or material indexers")
+    
     def _set_phases(self, phases):
         self._phases = phases = tuple(sorted(phases))
         cache = self._phase_index_cache
@@ -414,7 +477,7 @@ class MaterialIndexer(Indexer):
         except:
             raise UndefinedPhase(phase)
     
-    def iter_data(self):
+    def __iter__(self):
         """Iterate over phase-data pairs."""
         return zip(self._phases, self._data)
     
@@ -427,7 +490,7 @@ class MaterialIndexer(Indexer):
     def __format__(self, tabs="1"):
         IDs = self._chemicals.IDs
         phase_data = []
-        for phase, data in self.iter_data():
+        for phase, data in self:
             ID_data = repr_couples(", ", IDs, data)
             if ID_data:
                 phase_data.append(f"{phase}=[{ID_data}]")
@@ -512,7 +575,7 @@ def _new_Indexer(name, units):
     MaterialIndexerSubclass.__slots__ = ()
     
     ChemicalIndexerSubclass.units = \
-    MaterialIndexerSubclass.units = UnitsOfMeasure(units)
+    MaterialIndexerSubclass.units = AbsoluteUnitsOfMeasure(units)
     
     MaterialIndexerSubclass._ChemicalIndexer = ChemicalIndexerSubclass
     ChemicalIndexerSubclass._MaterialIndexer = MaterialIndexerSubclass
