@@ -4,7 +4,9 @@ All data and methods related to chemical combustion.
 """
 from .elements import compute_mass_fractions, compute_molecular_weight
 
-__all__ = ('CombustionData', 'estimate_HHV_modified_Dulong')
+__all__ = ('CombustionData',
+           'estimate_HHV_modified_Dulong',
+           'get_combustion_stoichiometry')
 
 # %% Combustion functions
 
@@ -30,7 +32,7 @@ Hf_combustion_products = {
 }
 
 def get_combustion_stoichiometry(atoms: dict, 
-                                 MW: float=None):
+                                 MW: float=None) -> dict:
     """
     Return a dictionary of the combustion stoichiometry of a chemical.
     
