@@ -614,7 +614,7 @@ def volume_liquid_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc,
             add_model(SNM0.from_args(data), 0, Tc)
     if CAS in _CRC_inorg_l_const:
         Vl = float(_CRC_inorg_l_const.at[CAS, 'Vm'])
-        add_model(Vl, Tmin, Tmax, name="CRC_inorganic_liquid_constant")
+        add_model(Vl, Tmin, Tmax, name="CRC inorganic liquid constant")
     if Tc and Pc and CAS in _COSTALD:
         Zc_ = _COSTALD.at[CAS, 'Z_RA']
         if not np.isnan(Zc_): Zc_ = float(Zc_)
